Crate sediment_core_plugin_wit

Crate sediment_core_plugin_wit 

This crate provides the WIT definitions for the sediment-core:plugin package. It does not contain any runtime code itself but is used by other crates to generate bindings and implement or consume the defined interfaces.